@@ -5,7 +5,6 @@ import errno
 
 import time
 from cloudshell.core.context.error_handling_context import ErrorHandlingContext
-from cloudshell.shell.core.context import ResourceCommandContext
 from cloudshell.shell.core.session.cloudshell_session import CloudShellSessionContext
 from cloudshell.shell.core.session.logging_session import LoggingSessionContext
 
@@ -42,7 +41,7 @@ class CustomScriptShell(object):
                     output_writer = ReservationOutputWriter(api, command_context)
 
                     logger.info('Downloading file from \'%s\' ...' % script_conf.script_repo.url)
-                    script_file = self._download_script(script_conf.script_repo, logger, cancel_sampler)
+                    script_file = self._download_script(script_conf.script_repo, logger, cancel_sampler, script_conf.verify_certificate)
                     logger.info('Done (%s, %s chars).' % (script_file.name, len(script_file.text)))
 
                     service = ScriptExecutorSelector.get(script_conf.host_conf, logger, cancel_sampler)
@@ -55,7 +54,7 @@ class CustomScriptShell(object):
 
                     service.execute(script_file, script_conf.host_conf.parameters, output_writer, script_conf.print_output)
 
-    def _download_script(self, script_repo, logger, cancel_sampler):
+    def _download_script(self, script_repo, logger, cancel_sampler, verify_certificate):
         """
         :type script_repo: ScriptRepository
         :type logger: Logger
@@ -66,7 +65,7 @@ class CustomScriptShell(object):
         auth = None
         if script_repo.username or script_repo.token:
             auth = HttpAuth(script_repo.username, script_repo.password, script_repo.token)
-        return ScriptDownloader(logger, cancel_sampler).download(url, auth)
+        return ScriptDownloader(logger, cancel_sampler).download(url, auth, verify_certificate)
 
     def _warn_for_unexpected_file_type(self, target_host, service, script_file, output_writer):
         """
