@@ -55,14 +55,14 @@ class WindowsScriptExecutor(IScriptExecutor):
             self.logger.info(stdout)
             assert uid in stdout
         except ConnectTimeout as e:
-            self.logger(e.response)
+            self.logger.error(e.response)
             raise ExcutorConnectionError(10060, e) #10060=Timeout
         except ConnectionError as e:
             match = re.search(r'\[Errno (?P<errno>\d+)\]', str(e))
             error_code = int(match.group('errno')) if match else 0
             raise ExcutorConnectionError(error_code, e)
         except WinRMTransportError as e:
-            match = re.search(r'Code (?P<errno>\d+)', str(e.message))
+            match = re.search(r'Code (?P<errno>\d+)', str(e))
             error_code = int(match.group('errno')) if match else 0
             raise ExcutorConnectionError(error_code, e)
         except Exception as e:
@@ -216,4 +216,4 @@ Remove-Item $path -recurse
                 self.logger.error('Succeeded to decode stderr : ' + str)
             except Exception as e:
                 self.logger.error('Failed to decode stderr. Error: %s' % e.msg)
-        return str
\ No newline at end of file
+        return str
